GeometryObject class abstract

Inheritance
Implementers

Constructors

GeometryObject.withType(GeoJSONObjectType type, {BBox? bbox})

Properties

bbox ↔ BBox?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → GeoJSONObjectType
finalinherited

Methods

clone() → GeoJSONObject
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(Map<String, dynamic> map) → Map<String, dynamic>
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deserialize(Map<String, dynamic> json) → GeometryObject